diff src/window.h @ 43619:03e9839bc157

(struct window): New member phys_cursor_width.
author Kim F. Storm <storm@cua.dk>
date Fri, 01 Mar 2002 22:36:09 +0000
parents b7964dae2379
children 44b653625dac
line wrap: on
line diff
--- a/src/window.h	Fri Mar 01 21:04:00 2002 +0000
+++ b/src/window.h	Fri Mar 01 22:36:09 2002 +0000
@@ -232,9 +232,9 @@
     /* Where the cursor actually is.  */
     struct cursor_pos phys_cursor;
     
-    /* Cursor type last drawn on the window.  Used for X frames; -1
-       initially.  */
-    int phys_cursor_type;
+    /* Cursor type and width of last cursor drawn on the window.  
+       Used for X and w32 frames; -1 initially.  */
+    int phys_cursor_type, phys_cursor_width;
 
     /* This is handy for undrawing the cursor.  */
     int phys_cursor_ascent, phys_cursor_height;